const openSearchClient = require( "../openSearchClient");

const searchHandler = (req, res) => {
  const { text, size = 10, page = 0 } = req.body;
  openSearchClient.search({
    index: 'apps-20000-sample',
    body: {
      from: page*size,
      size: size,
      query: {
        bool: {
          must: [
            { multi_match: {
                "query": text,
                "fields": ["app.name", "app.developer.name", "app.description.short", "app.description.full"]
              }
            },
            // { term: { "app.content_rating": 'everyone' } }
          ]
        },
        // "should":[],
        // "must_not": []
      },
      sort: {
        "_script" : {
          "script" : "params._source.app.scores[0].measure.score",
          "type" : "number",
          "order" : "asc"
        }
      }
    }
  })
    .then((response) => {
      console.log(response.body);
      res.send(response.body);
    })
    .catch((error) => {
      console.log(error.body.error.root_cause);
      res.status(404).json(error.body);
    })
}

module.exports = { searchHandler };